@@ -1,27 +1,31 @@
 from __future__ import division
-import time
+
+# import time
+
 import folium
 import numpy as np
 import pandas as pd
-from IPython.display import display
-from ipywidgets import IntProgress, HTML, VBox
-from pymove.utils.datetime import deltatime_str
-from pymove.utils.constants import LATITUDE, LONGITUDE, DATETIME, TRAJ_ID
+# from IPython.display import display
+# from ipywidgets import HTML, IntProgress, VBox
+
+from pymove.utils.constants import DATETIME, LATITUDE, LONGITUDE, TRAJ_ID
+# from pymove.utils.datetime import deltatime_str
 
 
 def read_csv(
     filename,
-    sep=',',
+    sep=",",
     encoding="utf-8",
     latitude=LATITUDE,
     longitude=LONGITUDE,
     datetime=DATETIME,
     traj_id=TRAJ_ID,
     type_="pandas",
-    n_partitions=1
+    n_partitions=1,
 ):
     """
-    Reads a .csv file and structures the data into the desired structure supported by PyMove.
+    Reads a .csv file and structures the data into the desired structure
+    supported by PyMove.
 
     Parameters
 
@@ -48,7 +52,7 @@ def read_csv(
         Represents the column name of feature id trajectory.
 
     type_ : String, optional, default 'pandas'.
-        Represents the type of                    \
+        Represents the type_ of                    \
 
     n_partitions : int, optional, default 1.
         Represents .
@@ -57,20 +61,23 @@ def read_csv(
     -------
     pymove.core.MoveDataFrameAbstract subclass.
         Trajectory data.
-
     """
-    df = pd.read_csv(filename, sep=sep, encoding=encoding, parse_dates=['datetime'])
+    df = pd.read_csv(
+        filename, sep=sep, encoding=encoding, parse_dates=["datetime"]
+    )
 
     from pymove import PandasMoveDataFrame as pm
     from pymove import DaskMoveDataFrame as dm
 
-    if type_ == 'pandas':
+    if type_ == "pandas":
         return pm(df, latitude, longitude, datetime, traj_id)
-    if type_ == 'dask':
+    if type_ == "dask":
         return dm(df, latitude, longitude, datetime, traj_id, n_partitions)
 
 
-def format_labels(move_data, current_id, current_lat, current_lon, current_datetime):
+def format_labels(
+    move_data, current_id, current_lat, current_lon, current_datetime
+):
     """
     Format the labels for the PyMove lib pattern labels output = lat, lon and datatime.
 
@@ -96,7 +103,7 @@ def format_labels(move_data, current_id, current_lat, current_lon, current_datet
     dic_labels : dict.
         Represents a dict with mapping current columns of data to format of PyMove column.
 
-    """ 
+    """
     dic_labels = {}
     dic_labels[current_id] = TRAJ_ID
     dic_labels[current_lon] = LONGITUDE
@@ -105,118 +112,131 @@ def format_labels(move_data, current_id, current_lat, current_lon, current_datet
     return dic_labels
 
 
-#TODO: COmpletar as infos
-def log_progress(sequence, every=None, size=None, name='Items'):
-    """
-    Make and display a progress bar.
-
-    Parameters
-    ----------
-    sequence : list.
-        Represents a elements sequence.
-
-    every : ?, optional, default None.
-        Represents the column name of feature id.
-
-    size : int, optional, default None.
-        Represents the size/number elements in sequence.
-
-    name : String, optional, default 'Items'.
-        Represents the name of ?.
-
-    Returns
-    -------
-
-    """
-    is_iterator = False
-    if size is None:
-        try:
-            size = len(sequence)
-        except TypeError:
-            is_iterator = True
-    if size is not None:
-        if every is None:
-            if size <= 200:
-                every = 1
-            else:
-                every = int(size/200)
-    else:
-        assert every is not None, 'sequence is iterator, set every'
-
-    if is_iterator:
-        progress = IntProgress(min=0, max=1, value=1)
-        progress.bar_style = 'info'
-    else:
-        progress = IntProgress(min=0, max=size, value=0)
-    label = HTML()
-    box = VBox(children=[label, progress])
-    display(box)
-
-    index = 0
-    try:
-        for index, record in enumerate(sequence, 1):
-            if index == 1 or index % every == 0:
-                if is_iterator:
-                    label.value = '{name}: {index} / ?'.format(name=name, index=index)
-                else:
-                    progress.value = index
-                    label.value = u'{name}: {index} / {size}'.format(
-                        name=name,
-                        index=index,
-                        size=size
-                    )
-            yield record
-    except:
-        progress.bar_style = 'danger'
-        raise
-    else:
-        progress.bar_style = 'success'
-        progress.value = index
-        label.value = "{name}: {index}".format(name=name, index=str(index or '?'))
+# TODO: COmpletar as infos
+# def log_progress(sequence, every=None, size=None, name="Items"):
+#     """
+#     Make and display a progress bar.
+#
+#     Parameters
+#     ----------
+#     sequence : list.
+#         Represents a elements sequence.
+#
+#     every : ?, optional, default None.
+#         Represents the column name of feature id.
+#
+#     size : int, optional, default None.
+#         Represents the size/number elements in sequence.
+#
+#     name : String, optional, default 'Items'.
+#         Represents the name of ?.
+#
+#     Returns
+#     -------
+#     """
+#     is_iterator = False
+#     if size is None:
+#         try:
+#             size = len(sequence)
+#         except TypeError:
+#             is_iterator = True
+#     if size is not None:
+#         if every is None:
+#             if size <= 200:
+#                 every = 1
+#             else:
+#                 every = int(size / 200)
+#     else:
+#         assert every is not None, "sequence is iterator, set every"
+#
+#     if is_iterator:
+#         progress = IntProgress(min=0, max=1, value=1)
+#         progress.bar_style = "info"
+#     else:
+#         progress = IntProgress(min=0, max=size, value=0)
+#     label = HTML()
+#     box = VBox(children=[label, progress])
+#     display(box)
+#
+#     index = 0
+#     try:
+#         for index, record in enumerate(sequence, 1):
+#             if index == 1 or index % every == 0:
+#                 if is_iterator:
+#                     label.value = "{name}: {index} / ?".format(
+#                         name=name, index=index
+#                     )
+#                 else:
+#                     progress.value = index
+#                     label.value = u"{name}: {index} / {size}".format(
+#                         name=name, index=index, size=size
+#                     )
+#             yield record
+#     except Exception:
+#         progress.bar_style = "danger"
+#         raise
+#     else:
+#         progress.bar_style = "success"
+#         progress.value = index
+#         label.value = "{name}: {index}".format(
+#             name=name, index=str(index or "?")
+#         )
 
 
-#TODO: COmpletar as infos
-def progress_update(size_processed, size_all, start_time, curr_perc_int, step_perc=1):
-    """
-    Update and print current progress.
-
-    Parameters
-    ----------
-    size_processed : int.
-        Represents a number of elements already processed.
-
-    size_all : int.
-        Represents the number of elements.
-
-    start_time : int, optional, default None.
-        Represents the size/number elements in sequence.
-
-    curr_perc_int : ?
-        Represents the name of ?.
-
-    step_perc : int, optional, default 1.
-        Represents the name of ?.
-
-    Returns
-    -------
-    curr_perc_int_new : ?
-        Represents ?.
-
-    deltatime_str : ?
-        Represents ?.
-
-    """
-    curr_perc_new = size_processed*100.0/size_all
-    curr_perc_int_new = int(curr_perc_new)
-    if curr_perc_int_new != curr_perc_int and curr_perc_int_new % step_perc == 0:
-        deltatime = time.time() - start_time
-        deltatime_str_ = deltatime_str(deltatime)
-        est_end = deltatime / curr_perc_new * 100
-        est_time_str = deltatime_str(est_end - deltatime)
-        print('({}/{}) {}% in {} - estimated end in {}'.format(size_processed, size_all, curr_perc_int_new, deltatime_str_, est_time_str))
-        return curr_perc_int_new, deltatime_str
-    else:
-        return curr_perc_int_new, None
+# TODO: COmpletar as infos
+# def progress_update(
+#     size_processed, size_all, start_time, curr_perc_int, step_perc=1
+# ):
+#     """
+#     Update and print current progress.
+#
+#     Parameters
+#     ----------
+#     size_processed : int.
+#         Represents a number of elements already processed.
+#
+#     size_all : int.
+#         Represents the number of elements.
+#
+#     start_time : int, optional, default None.
+#         Represents the size/number elements in sequence.
+#
+#     curr_perc_int : ?
+#         Represents the name of ?.
+#
+#     step_perc : int, optional, default 1.
+#         Represents the name of ?.
+#
+#     Returns
+#     -------
+#     curr_perc_int_new : ?
+#         Represents ?.
+#
+#     deltatime_str : ?
+#         Represents ?.
+#     """
+#     curr_perc_new = size_processed * 100.0 / size_all
+#     curr_perc_int_new = int(curr_perc_new)
+#     if (
+#         curr_perc_int_new != curr_perc_int
+#         and curr_perc_int_new % step_perc == 0
+#     ):
+#         deltatime = time.time() - start_time
+#         deltatime_str_ = deltatime_str(deltatime)
+#         est_end = deltatime / curr_perc_new * 100
+#         est_time_str = deltatime_str(est_end - deltatime)
+#         print(
+#             "({}/{}) {}% in {} - estimated end in {}".format(
+#                 size_processed,
+#                 size_all,
+#                 curr_perc_int_new,
+#                 deltatime_str_,
+#                 est_time_str,
+#             )
+#         )
+#         return curr_perc_int_new, deltatime_str
+#     else:
+#         return curr_perc_int_new, None
 
 
 def shift(arr, num, fill_value=np.nan):
@@ -238,7 +258,7 @@ def shift(arr, num, fill_value=np.nan):
     Returns
     -------
     result : array.
-        A new array with the same shape and type as the initial given array, but with the indexes shifted.
+        A new array with the same shape and type_ as the initial given array, but with the indexes shifted.
 
     Notes
     -----
@@ -247,7 +267,6 @@ def shift(arr, num, fill_value=np.nan):
     References
     --------
         https://stackoverflow.com/questions/30399534/shift-elements-in-a-numpy-array
-
     """
 
     result = np.empty_like(arr)
@@ -282,7 +301,7 @@ def shift(arr, num, fill_value=np.nan):
 #
 #     """
 #     for i in range(len(new_list_values)):
-#         type1 = type(original_list[i])
+#         type1 = type_(original_list[i])
 #         if type1 == int:
 #             original_list[i] = int(new_list_values[i])
 #         elif type1 == float:
@@ -291,20 +310,20 @@ def shift(arr, num, fill_value=np.nan):
 #             original_list[i] = new_list_values[i]
 
 
-def save_bbox(bbox_tuple, file, tiles='OpenStreetMap', color='red'):
+def save_bbox(bbox_tuple, file, tiles="OpenStreetMap", color="red"):
     """
     Save bbox as file .html using Folium.
 
     Parameters
     ----------
     bbox_tuple : tuple.
-        Represents a bound box, that is a tuple of 4 values with the min and max limits of latitude e longitude.
+        Represents a bound box, that is a tuple of 4 values with the min_ and max limits of latitude e longitude.
 
     file : String.
         Represents filename.
 
     tiles : String, optional, default 'OpenStreetMap'.
-        Represents tyles's type.
+        Represents tyles's type_.
         Example: 'openstreetmap', 'cartodbpositron', 'stamentoner', 'stamenterrain', 'mapquestopen',
         'MapQuest Open Aerial', 'Mapbox Control Room' and 'Mapbox Bright'.
 
@@ -320,12 +339,17 @@ def save_bbox(bbox_tuple, file, tiles='OpenStreetMap', color='red'):
     >>> from pymove.trajectories import save_bbox
     >>> bbox = (22.147577, 113.54884299999999, 41.132062, 121.156224)
     >>> save_bbox(bbox, 'bbox.html')
-
     """
     m = folium.Map(tiles=tiles)
-    m.fit_bounds([[bbox_tuple[0], bbox_tuple[1]], [bbox_tuple[2], bbox_tuple[3]]])
-    points_ = [(bbox_tuple[0], bbox_tuple[1]), (bbox_tuple[0], bbox_tuple[3]),
-               (bbox_tuple[2], bbox_tuple[3]), (bbox_tuple[2], bbox_tuple[1]),
-               (bbox_tuple[0], bbox_tuple[1])]
+    m.fit_bounds(
+        [[bbox_tuple[0], bbox_tuple[1]], [bbox_tuple[2], bbox_tuple[3]]]
+    )
+    points_ = [
+        (bbox_tuple[0], bbox_tuple[1]),
+        (bbox_tuple[0], bbox_tuple[3]),
+        (bbox_tuple[2], bbox_tuple[3]),
+        (bbox_tuple[2], bbox_tuple[1]),
+        (bbox_tuple[0], bbox_tuple[1]),
+    ]
     folium.PolyLine(points_, weight=3, color=color).add_to(m)
-    m.save(file)
\ No newline at end of file
+    m.save(file)
